# Custom logging class for Apache-Airflow

## Usage

After installing the package in the `Apache-Airflow` environment, set the `logging_config_class` option in the `airflow.cfg` file
and restart the `Apache-Airflow` application.